@@ -3,7 +3,7 @@ function(mydata, outcome = "", conditions = c(""), incl.rem = FALSE,
          expl.1 = FALSE, expl.0 = FALSE, expl.ctr = FALSE, expl.mo = FALSE,
          incl.1 = FALSE, incl.0 = FALSE, incl.ctr = FALSE, incl.mo = FALSE,
          quiet = FALSE, details = FALSE, chart = FALSE, use.letters = TRUE,
-         show.cases = FALSE, tt = FALSE) {
+         show.cases = FALSE, diffmatrix=TRUE) {
 
      # check if the data has column names
     if (is.null(colnames(mydata))) {
